@@ -1,43 +1,50 @@
 
-/*  sound_handling.cpp
+/* GnomeMeeting -- A Video-Conferencing application
+ * Copyright (C) 2000-2003 Damien Sandras
  *
- *  GnomeMeeting -- A Video-Conferencing application
- *  Copyright (C) 2000-2002 Damien Sandras
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ * GnomeMeting is licensed under the GPL license and as a special exception,
+ * you have permission to link or otherwise combine this program with the
+ * programs OpenH323 and Pwlib, and distribute the combination, without
+ * applying the requirements of the GNU GPL to the OpenH323 program, as long
+ * as you do follow the requirements of the GNU GPL for all the rest of the
+ * software thus combined.
  */
- 
+
+
 /*
  *                         sound_handling.cpp  -  description
  *                         ----------------------------------
  *   begin                : Thu Nov 22 2001
- *   copyright            : (C) 2000-2002 by Damien Sandras
+ *   copyright            : (C) 2000-2003 by Damien Sandras
  *   description          : This file contains sound handling functions.
- *   email                : dsandras@seconix.com
  *
  */
 
+#include "../config.h"
 
-#include "sound_handling.h"
 #include "common.h"
+#include "gnomemeeting.h"
+#include "sound_handling.h"
 #include "endpoint.h"
 #include "misc.h"
 #include "tray.h"
 #include "dialog.h"
 
-#include <ptlib.h>
 
 #ifdef __FreeBSD__
 #include <sys/types.h>
@@ -48,13 +55,16 @@
 #include <ixjlid.h>
 #endif
 
-#ifndef DISABLE_GNOME
-#include <gnome.h>
+#ifdef __linux__
+#include <linux/soundcard.h>
 #endif
 
+
+
 static void dialog_response_cb (GtkWidget *, gint, gpointer);
 
 extern GtkWidget *gm;
+extern GnomeMeeting *MyApp;
 
 
 /* The GTK callbacks */
@@ -62,7 +72,7 @@ void dialog_response_cb (GtkWidget *w, gint, gpointer data)
 {
   GmDruidWindow *dw = NULL;
 
-  dw = gnomemeeting_get_druid_window (gm);
+  dw = MyApp->GetDruidWindow ();
 
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dw->audio_test_button),
 				false);
@@ -75,40 +85,51 @@ void dialog_response_cb (GtkWidget *w, gint, gpointer data)
 void 
 gnomemeeting_sound_daemons_suspend (void)
 {
+#ifndef WIN32
+#if defined(HAS_ESD)
+  return;
+#else
   int esd_client = 0;
   
   /* Put ESD into standby mode */
   esd_client = esd_open_sound (NULL);
 
-  if (esd_standby (esd_client) != 1) 
-    PTRACE (0, "Failed to resume ESD");
+  esd_standby (esd_client);
       
   esd_close (esd_client);
+#endif
+#endif
 }
 
 
 void 
 gnomemeeting_sound_daemons_resume (void)
 {
+#ifndef WIN32
+#if defined(HAS_ESD)
+  return;
+#else
   int esd_client = 0;
 
   /* Put ESD into normal mode */
   esd_client = esd_open_sound (NULL);
 
-  if (esd_resume (esd_client) != 1) 
-    PTRACE (0, "Failed to resume ESD");
+  esd_resume (esd_client);
 
   esd_close (esd_client);
+#endif
+#endif
 }
 
 
 void 
 gnomemeeting_mixers_mic_select (void)
 {
+#ifndef WIN32
+#ifndef P_MACOSX
   int rcsrc = 0;
   int mixerfd = -1;                                                            
   int cpt = -1;
-                                                                       
   PString mixer_name = PString ("/dev/mixer");
   PString mixer = mixer_name;
 
@@ -130,11 +151,16 @@ gnomemeeting_mixers_mic_select (void)
       close (mixerfd);
     }
   }
+#else
+  return;
+#endif
+#endif
 }
 
 
 int gnomemeeting_get_mixer_volume (char *mixer, int source)
 {
+#ifndef P_MACOSX
   int vol = 0;
   int mixerfd = -1;
   
@@ -154,11 +180,16 @@ int gnomemeeting_get_mixer_volume (char *mixer, int source)
 
   close (mixerfd);
   return vol;
+#else
+  return 0;
+#endif  
 }
 
 
 void gnomemeeting_set_mixer_volume (char *mixer, int source, int vol)
 {
+#ifndef WIN32
+#ifndef P_MACOSX
   int mixerfd = -1;
   
   if (!mixer)
@@ -176,6 +207,10 @@ void gnomemeeting_set_mixer_volume (char *mixer, int source, int vol)
     ioctl (mixerfd, MIXER_WRITE (SOUND_MIXER_MIC), &vol);
   
   close (mixerfd);
+#else
+  return;
+#endif
+#endif
 }
 
 
@@ -277,7 +312,7 @@ gnomemeeting_sound_play_ringtone (GtkWidget *widget)
      are executed in the main thread */
 #ifndef DISABLE_GNOME
   gdk_threads_enter ();
-  gboolean is_ringing = gnomemeeting_tray_is_ringing (G_OBJECT (widget));
+  gboolean is_ringing = gnomemeeting_tray_is_ringing (widget);
   gdk_threads_leave ();
 
   /* If the systray icon contains the ringing pic */
@@ -302,7 +337,7 @@ GMAudioTester::GMAudioTester (GMH323EndPoint *e)
   
   gnomemeeting_sound_daemons_suspend ();
   gnomemeeting_threads_enter ();
-  gw = gnomemeeting_get_main_window (gm);
+  gw = MyApp->GetMainWindow ();
   gnomemeeting_threads_leave ();
 
   player = new PSoundChannel;
@@ -376,7 +411,7 @@ void GMAudioTester::Main ()
 		     1, 8000, 16)) {
 
     gdk_threads_enter ();  
-    gnomemeeting_error_dialog (GTK_WINDOW (gw->druid_window), _("Impossible to open the selected audio device (%s) for playing. Please check your audio setup."), (const char *) ep->GetSoundChannelPlayDevice ());
+    gnomemeeting_error_dialog (GTK_WINDOW (gw->druid_window), _("Failed to open the device"), _("Impossible to open the selected audio device (%s) for playing. Please check your audio setup, the permissions and that the device is not busy."), (const char *) ep->GetSoundChannelPlayDevice ());
     gdk_threads_leave ();  
 
     stop = TRUE;
@@ -388,11 +423,16 @@ void GMAudioTester::Main ()
 		       1, 8000, 16)) {
 
     gdk_threads_enter ();  
-    gnomemeeting_error_dialog (GTK_WINDOW (gw->druid_window), _("Impossible to open the selected audio device (%s) for recording. Please check your audio setup."), (const char *) ep->GetSoundChannelRecordDevice ());
+    gnomemeeting_error_dialog (GTK_WINDOW (gw->druid_window), _("Failed to open the audio device"), _("Impossible to open the selected audio device (%s) for recording. Please check your audio setup, the permissions and that the device is not busy."), (const char *) ep->GetSoundChannelRecordDevice ());
     gdk_threads_leave ();  
 
     stop = TRUE;
   }
+  
+#ifdef P_MACOSX
+  recorder->SetBuffers (512, 1);
+  player->SetBuffers (512, 1);
+#endif
 
   quit_mutex.Wait ();
 
@@ -402,7 +442,7 @@ void GMAudioTester::Main ()
     if (!recorder->Read ((void *) buffer_record, 8 * 1024)) {
       
       gdk_threads_enter ();  
-      gnomemeeting_error_dialog (GTK_WINDOW (gw->druid_window), _("The selected audio device (%s) was successfully opened but it is impossible to read data from this device. Please check your audio setup."), (const char*) ep->GetSoundChannelRecordDevice ());
+      gnomemeeting_error_dialog (GTK_WINDOW (gw->druid_window), _("Cannot use the audio device"), _("The selected audio device (%s) was successfully opened but it is impossible to read data from this device. Please check your audio setup."), (const char*) ep->GetSoundChannelRecordDevice ());
       gdk_threads_leave ();  
 
       stop = TRUE;
@@ -411,7 +451,7 @@ void GMAudioTester::Main ()
 	     && !player->Write ((void *) buffer_play, 8 * 1024)) {
 
       gdk_threads_enter ();  
-      gnomemeeting_error_dialog (GTK_WINDOW (gw->druid_window), _("The selected audio device (%s) was successfully opened but it is impossible to write data to this device. Please check your audio setup."), (const char*) ep->GetSoundChannelPlayDevice ());
+      gnomemeeting_error_dialog (GTK_WINDOW (gw->druid_window), _("Cannot use the audio device"), _("The selected audio device (%s) was successfully opened but it is impossible to write data to this device. Please check your audio setup."), (const char*) ep->GetSoundChannelPlayDevice ());
       gdk_threads_leave ();  
 	
       stop = TRUE;
@@ -479,7 +519,7 @@ void GMAudioTester::Main ()
   }
 
   gnomemeeting_threads_enter ();
-  dw = gnomemeeting_get_druid_window (gm);
+  dw = MyApp->GetDruidWindow ();
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dw->audio_test_button),
 				FALSE);
   gtk_widget_queue_draw (dw->audio_test_button);
